@@ -31,4 +31,9 @@ setGeneric('plotChromatogram',function(x){
 #' @rdname plotTIC
 setGeneric('plotTIC',function(x, by = 'injOrder', colour = 'block'){
 	standardGeneric('plotTIC')
+})
+
+#' @rdname plotFingerprint
+setGeneric('plotFingerprint',function(x){
+	standardGeneric('plotFingerprint')
 })
\ No newline at end of file
